# AI Hero Python SDK

## Installation

Install AI Hero using pip:

```bash
pip install aihero==0.4
```

## How to use it

In a folder for your project, create a file `.env` containing the following API Keys:

```
AI_HERO_PROJECT_ID=<Project ID from your project the AI Hero Website>
AI_HERO_API_KEY=<API Key for the project>
```

## Examples

Check out the examples in the [examples](examples/) directory.

There's more coming soon!

- We're building a notebook for Retrieval Augmented Generation.
- Hit us up if you'd like a custom demo at `team@aihero.studio`.
